@@ -13,6 +13,7 @@ import re
 sys.path.append(Path(__file__).resolve().parent.parent.__str__()) ## this line is for development
 import dtiplayground
 import dtiplayground.dmri.common
+import dtiplayground.dmri.common.module
 from dtiplayground.config import INFO as info
 
 logger=dtiplayground.dmri.common.logger.write 
@@ -449,9 +450,9 @@ def command_init(args):
     software_filename=home_dir.joinpath('software_paths.yml')
     update_software_paths(args, globalvars)
     logger("Software path file is written to : {}".format(str(software_filename)),color.INFO)
-
-    modules=dtiplayground.dmri.preprocessing.modules.load_modules(user_module_paths=config['user_module_directories'])
-    environment=dtiplayground.dmri.preprocessing.modules.generate_module_envionrment(modules,str(home_dir))
+    system_module_paths = [Path(dtiplayground.__file__).resolve().parent.joinpath('dmri/preprocessing/modules')]
+    modules=dtiplayground.dmri.common.module.load_modules(system_module_paths = system_module_paths, user_module_paths=config['user_module_directories'])
+    environment=dtiplayground.dmri.common.module.generate_module_envionrment(modules,str(home_dir))
     yaml.dump(environment,open(environment_filename,'w'))
     logger("Environment file written to : {}".format(str(environment_filename)),color.INFO)
     logger("Initialized. Local configuration will be stored in {}".format(str(home_dir)),color.OK)
@@ -471,8 +472,9 @@ def command_update(args):
     ## load config_file
     config=yaml.safe_load(open(config_filename,'r'))
     ## make environment file (environment.yml)
-    modules=dtiplayground.dmri.preprocessing.modules.load_modules(user_module_paths=config['user_module_directories'])
-    environment=dtiplayground.dmri.preprocessing.modules.generate_module_envionrment(modules,str(home_dir))
+    system_module_paths = [Path(dtiplayground.__file__).resolve().parent.joinpath('dmri/preprocessing/modules')]
+    modules=dtiplayground.dmri.common.module.load_modules(system_module_paths = system_module_paths,user_module_paths=config['user_module_directories'])
+    environment=dtiplayground.dmri.common.module.generate_module_envionrment(modules,str(home_dir))
     yaml.dump(environment,open(environment_filename,'w'))
     logger("Environment file written to : {}".format(str(environment_filename)),color.INFO)
     logger("Initialized. Local configuration will be stored in {}".format(str(home_dir)),color.OK)
@@ -514,12 +516,15 @@ def command_add_module(args):
         module_template_fn =Path(dtiplayground.__file__).resolve().parent.joinpath("dmri/preprocessing/templates/module_template.py")
         module_template = open(module_template_fn,'r').read()
         module_data_fn = module_template_fn.parent.joinpath('module_template.yml')
+        module_readme_fn = module_template_fn.parent.joinpath('module_template.md')
         module_data = open(module_data_fn,'r').read()
-
+        module_readme = open(module_readme_fn,'r').read()
         ### replacing variable
         regex=r"@MODULENAME@"
         module_py = re.sub(regex,module_name,module_template,0)
         module_yml = re.sub(regex,module_name,module_data,0)
+        module_md = re.sub(regex,module_name, module_readme, 0)
+
         ### write down files into user module dir
 
         init_fn = module_dir.joinpath("__init__.py")
@@ -531,6 +536,10 @@ def command_add_module(args):
         out_yml_fn = module_dir.joinpath("{}.yml".format(module_name))
         with open(out_yml_fn,'w') as f:
             f.write(module_yml)
+        out_md_fn = module_dir.joinpath("README.md")
+        with open(out_md_fn,'w') as f:
+            f.write(module_md)
+        
         logger("Module is added, please implement the module {} in {}".format(module_name, module_dir.__str__()), color.OK)
     else: ### copy base module to new one (new name)
         base_module_dir= None
@@ -758,7 +767,7 @@ def get_args():
     parser_run.add_argument('-g','--global-variables',help='Global Variables',type=str,nargs='*',required=False)
     parser_run.add_argument('-o','--output-dir',help="Output directory",type=str,required=True)
     parser_run.add_argument('--output-file-base', help="Output filename base", type=str, required=False)
-    parser_run.add_argument('-t','--num-threads',help="Number of threads to use",default=None,type=int,required=False)
+    parser_run.add_argument('-t','--num-threads',help="Number of threads to use",default=1,type=int,required=False)
     parser_run.add_argument('--no-output-image',help="No output Qced file will be generated",default=False,action='store_true')
     parser_run.add_argument('-b','--b0-threshold',metavar='BASELINE_THRESHOLD',help='b0 threshold value, default=10',default=10,type=float)
     parser_run.add_argument('-f','--output-format',metavar='OUTPUT FORMAT',default=None,help='OUTPUT format, if not specified, same format will be used for output  (NRRD | NIFTI)',type=str)
